@@ -30,8 +30,16 @@ Doc.set_extension('sentence_bert', getter=get_vector, force=True)
 def sentence_bert_factory(nlp, name, model_name, debug):
     if model_name:
         # esplicitly chosen
-        if model_name not in util.configs:
-            raise ValueError(f'Model "{model_name}" not available. Please choose one of {list(util.configs.keys())}')
+        if model_name in util.configs:
+            # one of the known ones
+            config = util.configs[model_name]
+            model_name = config['name']
+        else:
+            # may be a SentenceBert model name directly
+            try:
+                return SentenceBert(model_name, debug=debug)
+            except:
+                raise ValueError(f'Model "{model_name}" not available. Please choose one of {list(util.configs.keys())} or use one of the allowed values by SentenceBert.')
     else:
         # try to map from existing nlp
         # the language code needs to match
@@ -41,17 +49,15 @@ def sentence_bert_factory(nlp, name, model_name, debug):
         model_name = f'{meta_lang}_{meta_name}'
         if model_name not in util.configs:
             raise ValueError(f'Could not map nlp.meta["lang"]={meta_lang} and nlp.meta["name"]={meta_name} to an existing model.\n'
-                    f'Please set the parameter "model_name" to one of {list(util.configs.keys())}')
-    config = util.configs[model_name]
-    return SentenceBert(config, debug=debug)
+                    f'Please set the parameter "model_name" to one of {list(util.configs.keys())} or to a SentenceBert model name.')
+    return SentenceBert(model_name, debug=debug)
 
 
 class SentenceBert(object):
 
     models = {}
 
-    def __init__(self, config, debug) -> None:
-        model_name = config['name']
+    def __init__(self, model_name: str, debug: bool) -> None:
         self.model = SentenceBert.get_model(model_name)
         self.model_name = model_name
 
@@ -61,7 +67,7 @@ class SentenceBert(object):
         return doc
 
     @staticmethod
-    def get_model(model_name):
+    def get_model(model_name: str):
         if model_name in SentenceBert.models:
             model = SentenceBert.models[model_name]
         else:
@@ -79,10 +85,10 @@ def set_hooks(doc):
 
 
 def create_nlp(model_name, nlp=None):
-    if model_name not in util.configs:
-        raise ValueError(f'Model "{model_name}" not available')
-    config = util.configs[model_name]
     if not nlp:
+        if model_name not in util.configs:
+            raise ValueError(f'Model "{model_name}" not available')
+        config = util.configs[model_name]
         nlp = spacy.blank(config['spacy_base_model'])
         nlp.add_pipe('sentencizer')
     nlp.add_pipe('sentence_bert', config={'model_name': model_name}, first=True)
